@@ -1,6 +1,6 @@
 package Dancer::Plugin::Email;
 BEGIN {
-  $Dancer::Plugin::Email::VERSION = '0.1201';
+  $Dancer::Plugin::Email::VERSION = '0.1202';
 }
 # ABSTRACT: Simple email handling for Dancer applications using Email::Stuff!
 
@@ -43,9 +43,7 @@ register email => sub {
     }
     
     # process reply_to
-    if ($options->{reply_to}) {
-        $self->header("Return-Path" => $options->{reply_to});
-    }
+    $self->header("Reply-To" => $options->{reply_to}) if $options->{reply_to};
     
     # process subject
     if ($options->{subject}) {
@@ -53,22 +51,21 @@ register email => sub {
     }
     
     # process message
-    if ($options->{message}) {
+    my $message = $options->{message};
+    my $type = $options->{type} || '';
+    if ($message) {
         # multipart send using plain text and html
-        if (lc($options->{type}) eq 'multi') {
-            if (ref($options->{message}) eq "HASH") {
-                $self->html_body($options->{message}->{html})
-                    if defined $options->{message}->{html};
-                $self->text_body($options->{message}->{text})
-                    if defined $options->{message}->{text};
-            }
+        if ($type eq 'multi') {
+            die 'message param must be a hashref if type is multi'
+                unless ref $message eq 'HASH';
+            $self->html_body($message->{html}) if defined $message->{html};
+            $self->text_body($message->{text}) if defined $message->{text};
         }
         else {
             # standard send using html or plain text
-            if (lc($options->{type}) eq 'html') {
+            if ($type eq 'html') {
                 $self->html_body($options->{message});
-            }
-            else {
+            } else {
                 $self->text_body($options->{message});
             }
         }
@@ -91,10 +88,6 @@ register email => sub {
         }
     }
 
-    # some light error handling
-    die 'specify type multi if sending text and html'
-        if lc($options->{type}) eq 'multi' && "HASH" eq ref $options->{type};
-        
     # okay, go team, go
     if (defined $settings->{driver}) {
         if (lc($settings->{driver}) eq lc("sendmail")) {
@@ -159,7 +152,7 @@ Dancer::Plugin::Email - Simple email handling for Dancer applications using Emai
 
 =head1 VERSION
 
-version 0.1201
+version 0.1202
 
 =head1 SYNOPSIS
 
@@ -338,10 +331,20 @@ should be specified as, for example:
         host: localhost # for SMTP
         from: me@website.com
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Al Newkirk <awncorp@cpan.org>
 
+=item *
+
+Naveed Massjouni <ironcamel@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2010 by awncorp.
